@@ -134,14 +134,15 @@ class CustomerDetailsSchema(Schema):
     billing_address = fields.List(fields.Str())
     shipping_address = fields.List(fields.Str())
 
-class CustomExpirySchmea(Schema):
+class CustomExpirySchema(Schema):
     order_time = fields.Str()
     expiry_duration = fields.Str()
     unit = fields.Str()
 
     @validates('unit')
     def validate_unit(self, data):
-        if data not in ['second', 'minute', 'hour', 'day']
+        if data not in ['second', 'minute', 'hour', 'day']:
+            raise ValidationError('Unit must be either second, minute, hour or day.')
 
     @validates('expiry_duration')
     def validate_expiry_duration(self, data):
